@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+microstrategy_icon= Icon(
     title="MicroStrategy",
     slug="microstrategy",
     hex="D9232E",
     source="https://www.microstrategy.com/en/company/press-kit",
-    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>MicroStrategy icon</title><path d="M9.095 2.572h5.827v18.856H9.096zM0 2.572h5.825v18.856H.001zm18.174 0v18.854H24V8.33z"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>MicroStrategy</title><path d="M9.095 2.572h5.827v18.856H9.096zM0 2.572h5.825v18.856H.001zm18.174 0v18.854H24V8.33z"/></svg>""",
     guidelines='https://www.microstrategy.com/en/company/press-kit',
     license=None,
 )
